==> haskell-generic-trie-0.3.0.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-trie
version: 0.3.0.2
id: generic-trie-0.3.0.2-EIR9ZFppHWlFQO9DGnRD8y
key: generic-trie-0.3.0.2-EIR9ZFppHWlFQO9DGnRD8y
license: BSD3
maintainer: emertens@gmail.com
homepage: http://github.com/glguy/tries
synopsis: A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.
category: Data
author: Eric Mertens
exposed: True
exposed-modules:
    Data.GenericTrie Data.GenericTrie.Internal
abi: 7a67db416c986ee7f2460aa103a04502
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/generic-trie-0.3.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/generic-trie-0.3.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/generic-trie-0.3.0.2
hs-libraries: HSgeneric-trie-0.3.0.2-EIR9ZFppHWlFQO9DGnRD8y
depends:
    base-4.9.0.0 containers-0.5.7.1 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock
haddock-html: /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-trie-0.3.0.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-trie
version: 0.3.0.2
id: generic-trie-0.3.0.2-3dNkiC0LOP88iUF2z6cR8j
key: generic-trie-0.3.0.2-3dNkiC0LOP88iUF2z6cR8j
license: BSD3
maintainer: emertens@gmail.com
homepage: http://github.com/glguy/tries
synopsis: A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.
category: Data
author: Eric Mertens
exposed: True
exposed-modules:
    Data.GenericTrie Data.GenericTrie.Internal
abi: f95010b6a40acb1e2c21a6620cd243c1
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/generic-trie-0.3.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/generic-trie-0.3.0.2
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/generic-trie-0.3.0.2
hs-libraries: HSgeneric-trie-0.3.0.2-3dNkiC0LOP88iUF2z6cR8j
depends:
    base-4.9.1.0 containers-0.5.7.1 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock
haddock-html: /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
